package com.njyunzhi.avatar.person.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.njyunzhi.avatar.common.BaseController;
import com.njyunzhi.avatar.common.HttpUtils;
import com.njyunzhi.avatar.common.ResponseBean;
import com.njyunzhi.avatar.common.StringUtils;
import com.njyunzhi.avatar.person.service.StRankService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;
import com.njyunzhi.avatar.person.entity.TaPerson;
import com.njyunzhi.avatar.person.service.TaPersonService;

import java.util.Locale;

/**
 * 人员表;(ta_person)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-9-27
 */
@Api(tags = "人员表对象功能接口")
@RestController
@RequestMapping("/wx")
public class TaPersonController extends BaseController {
    
    @Autowired
    private TaPersonService taPersonService;

    @Autowired
    StRankService stRankService;

    @Value("${yz.amap.key}")
    String amapKey;

    @Value("${yz.amap.webapi}")
    String amapApi;

    @Autowired
    HttpUtils httpUtils;

    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/taPerson")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {
        
        IPage<TaPerson> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<TaPerson> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<TaPerson> result = taPersonService.page(pg);
        
        return ResponseBean.success(result);
    }

    /** 
     * 更新数据
     *
     * @param taPerson 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/taPerson")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody TaPerson taPerson) throws Exception {

        TaPerson origin = currentPerson();

        try {
            String location = taPerson.getLocation();
            if (!StringUtils.isEmpty(location) && (!location.equals(origin.getLocation()) || StringUtils.isEmpty(origin.getAreaCode()))) {
                location = StringUtils.urlEncode(location);
                String url = amapApi + "/v3/geocode/regeo?key=" + amapKey + "&location=" + location;
                String resp = httpUtils.get(url);
                JSONObject jsonObject = JSON.parseObject(resp);
                String infoCode = jsonObject.getString("infocode");
                if ("10000".equals(infoCode)) {
                    JSONObject regeoCodes = jsonObject.getJSONObject("regeocode");
                    JSONObject address = regeoCodes.getJSONObject("addressComponent");
                    taPerson.setAreaCode(address.getString("adcode"));

                    stRankService.createRank("area", taPerson.getAreaCode());
                    stRankService.updateByArea(taPerson.getAreaCode());
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }

        taPerson.setPersonId(origin.getPersonId());
        taPersonService.updateById(taPerson);
        return ResponseBean.success(taPerson);
    }

}