package com.njyunzhi.avatar.person.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.njyunzhi.avatar.common.StringUtils;
import com.njyunzhi.avatar.person.entity.TaPerson;
import com.njyunzhi.avatar.person.mapper.TaPersonMapper;
import com.njyunzhi.avatar.person.vo.RankItem;
import com.njyunzhi.avatar.service.impl.BaseServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;
import com.njyunzhi.avatar.person.entity.StRank;
import com.njyunzhi.avatar.person.mapper.StRankMapper;
import com.njyunzhi.avatar.person.service.StRankService;

/**
 * 统计排行;(st_rank)表服务实现类
 *
 * @author : http://www.chiner.pro
 * @date : 2022-9-27
 */
@Service
public class StRankServiceImpl extends BaseServiceImpl<StRankMapper, StRank> implements StRankService {

    @Autowired
    TaPersonMapper taPersonMapper;

    @Override
    public StRank createRank(String type, String code) {
        QueryWrapper<StRank> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("st_type", type);
        queryWrapper.eq("st_code", code);

        StRank stRank = getOne(queryWrapper);
        if (null == stRank) {
            stRank = new StRank();
            stRank.setStType(type);
            stRank.setStCode(code);
            stRank.setStNum(0);
            save(stRank);

            return stRank;
        }

        return stRank;
    }

    @Override
    public boolean updateByArea(String areaCode) {
        return baseMapper.increment("area", areaCode) > 0;
    }

    @Async
    @Override
    public void updateByPerson(Integer personId) {
        // 先将当前人员的 +1
        baseMapper.increment("person", personId.toString());

        // 递归更新
        TaPerson taPerson = taPersonMapper.selectById(personId);
        if (null != taPerson && null != taPerson.getRecommender()) {
            updateByPerson(taPerson.getRecommender());
        }
    }

    @Override
    public long getRankBy(String stType, String stCode) {
        return baseMapper.getRankBy(stType, stCode);
    }

    @Override
    public IPage<RankItem> getPageBy(IPage<RankItem> pg, String type) {
        return baseMapper.getPageBy(pg, type);
    }
}